<?php
/**
 * @package      VP Conversion Tracking
 *
 * @copyright    Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license      GNU General Public License version 2 or later; see LICENSE.txt
 * @authors      Abhishek Das <info@virtueplanet.com>
 * @link         https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

class VPCTHelperRouter extends JObject
{
	protected static $alias = null;
	
	protected static $activeMenuItem = 0;
	
	protected static $vmMenuItems = null;
	
	protected static $home = 0;
	
	protected $processAfter = false;
	
	public function buildRouteBefore(&$router, &$uri)
	{
		$query = $uri->getQuery(true);

		if (!empty($query['option']) && $query['option'] == 'com_virtuemart' && !empty($query['view']) && $query['view'] == 'thankyou')
		{
			$alias = self::getThankyouPageAlias();
			
			if (!empty($alias))
			{
				$this->processAfter = true;
				
				unset($query['option'], $query['view'], $query['layout'], $query['Itemid']);
				$uri->setQuery($query);
			}
			else
			{
				$this->processAfter = false;
			}
		}
		else
		{
			$this->processAfter = false;
		}
	}
	
	public function buildRouteAfter(&$router, &$uri)
	{
		if ($this->processAfter)
		{
			$app   = JFactory::getApplication();
			$path  = $uri->getPath();
			$alias = self::getThankyouPageAlias();
			
			if (version_compare(JVERSION, '4.0.0', 'ge') && $app->get('sef_suffix'))
			{
				$alias .= '.html';
			}
			
			$path  = $path . '/' . $alias;
			
			$uri->setPath($path);
		}
	}
	
	public function parseRoute(&$router, &$uri)
	{
		$app    = JFactory::getApplication();
		$rawUri = JUri::getInstance();
		$route  = $rawUri->getPath();
		$root   = JUri::root(true) . '/';
		$root_2 = $root . 'index.php/';
		
		if (strpos($route, $root_2) === 0)
		{
			$route = substr($route, strlen($root_2));
		}
		elseif (strpos($route, $root) === 0)
		{
			$route = substr($route, strlen($root));
		}

		// Remove the suffix
		if ($app->get('sef_suffix'))
		{
			if ($suffix = pathinfo($route, PATHINFO_EXTENSION))
			{
				$route = str_replace('.' . $suffix, '', $route);
			}
		}
		
		$vars = $uri->getQuery(true);

		if (!empty($route))
		{
			// Parse the application route
			$segments = explode('/', $route);
			$segments = array_values(array_filter($segments));
			$alias    = self::getThankyouPageAlias();
			$count    = count($segments);
			$sefs     = JLanguageHelper::getLanguages('sef');
			$part_1   = isset($segments[0]) ? $segments[0] : '';

			if (($count == 1 && $part_1 == $alias) || ($count == 2 && isset($sefs[$part_1]) && $segments[1] == $alias) || ($count == 2 && $segments[1] == $alias))
			{
				$vars['option'] = 'com_virtuemart';
				$vars['view']   = 'thankyou';
				
				$app->input->set('option', 'com_virtuemart');
				$app->input->set('view', 'thankyou');
				
				if ($count == 2 && isset($sefs[$part_1]) && !isset($vars['lang']))
				{
					$vars['lang'] = $part_1;
					$app->input->set('lang', $part_1);
				}

				if ($Itemid = self::getItemid())
				{
					$vars['Itemid']       = (int) $Itemid;
					self::$activeMenuItem = $vars['Itemid'];
					
					$app->input->set('Itemid', $vars['Itemid']);
				}
				
				// Set request as POST to avoid page cache
				if (!empty($_SERVER) && is_array($_SERVER))
				{
					$_SERVER['REQUEST_METHOD'] = 'POST';
					$_POST['option']           = $vars['option'];
					$_POST['view']             = $vars['view'];
				}
				
				$_REQUEST['view'] = $vars['view'];
				$_GET['view']     = $vars['view'];
				
				$uri->setPath('');
				$uri->setQuery($vars);
				$rawUri->setPath('');
				$rawUri->setQuery($vars);
			}
		}

		return $vars;
	}
	
	public static function getActiveMenuItem()
	{
		return self::$activeMenuItem;
	}
	
	public static function getThankyouPageAlias()
	{
		if (self::$alias === null)
		{
			$app  = JFactory::getApplication('site');
			$menu = $app->getMenu();
			
			if (!$menu)
			{
				return false;
			}
			
			self::$alias = false;
			self::$vmMenuItems = array();
			self::$vmMenuItems['category'] = array();
			
			$items   = $menu->getItems(array(), array(), false);
			$aliases = array('thankyou', 'thank-you', 'thankyou-for-your-order', 'thank-you-for-your-order', 'thankyou-page', 'order-thankyou', 'order-thankyou-page');

			foreach($items as $item)
			{
				if ($item->type == 'component' && isset($item->query['option']) && $item->query['option'] == 'com_virtuemart' && !empty($item->query['view']))
				{
					$view = $item->query['view'];
					
					if ($view == 'category')
					{
						if (isset($item->query['virtuemart_category_id']))
						{
							$category_id = (int) $item->query['virtuemart_category_id'];
							
							self::$vmMenuItems['category'][$category_id] = $item;
						}
					}
					else
					{
						self::$vmMenuItems[$view] = $item->id;
					}
				}
				
				if ($item->home)
				{
					self::$home = $item->id;
				}
				
				if ($item->parent_id > 1 || $item->type == 'menulink')
				{
					continue;
				}

				$alias_lower = strtolower($item->alias);
				
				if (in_array($item->alias, array($aliases)))
				{
					$key = array_search($item->alias, $aliases);
					unset($aliases[$key]);
				}
				elseif (in_array($alias_lower, array($aliases)))
				{
					$key = array_search($alias_lower, $aliases);
					unset($aliases[$key]);
				}
			}
			
			if (count($aliases))
			{
				reset($aliases);
				
				self::$alias = current($aliases);
			}
		}
		
		return self::$alias;
	}
	
	protected static function getItemid()
	{
		if (self::$vmMenuItems === null)
		{
			self::getThankyouPageAlias();
		}

		if (empty(self::$vmMenuItems))
		{
			return false;
		}

		if (isset(self::$vmMenuItems['cart']))
		{
			return self::$vmMenuItems['cart'];
		}
		
		if (isset(self::$vmMenuItems['virtuemart']))
		{
			return self::$vmMenuItems['virtuemart'];
		}
		
		if (!empty(self::$vmMenuItems['category']))
		{
			if (isset(self::$vmMenuItems['category'][0]))
			{
				return self::$vmMenuItems['category'][0]->id;
			}
			
			foreach(self::$vmMenuItems['category'] as $catMenu)
			{
				if ($catMenu->parent_id == 1)
				{
					return $catMenu->id;
				}
			}
			
			if ($first_catMenu = current(self::$vmMenuItems['category']))
			{
				return $first_catMenu->id;
			}
		}
		
		unset(self::$vmMenuItems['category']);
		
		if (!empty(self::$vmMenuItems))
		{
			return current(self::$vmMenuItems);
		}
		
		if (self::$home > 0)
		{
			return self::$home;
		}
		
		return false;
	}
}
