<?php

/**
 * @package      VP Conversion Tracking
 *
 * @copyright    Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license      GNU General Public License version 2 or later; see LICENSE.txt
 * @author       Abhishek Das <info@virtueplanet.com>
 * @link         https://www.virtueplanet.com
 */

// phpcs:disable PSR1.Files.SideEffects
defined('_JEXEC') or die;
// phpcs:enable PSR1.Files.SideEffects

// Define VP Conversion Tracking base path
defined('VPCT_PATH') or define('VPCT_PATH', __DIR__);

// debugging function vpdump()
if (!function_exists('vpdump')) {
    function vpdump($data, $debug = true)
    {
        ob_start();
        print_r($data);
        $str = ob_get_contents();
        ob_end_clean();

        echo '<pre class="vpdump" dir="ltr" style="font-size: 14px;">';
        echo '<small>' . gettype($data) . '</small> ';
        echo '<font color="#cc0000">' . $str . '</font>';
        echo '<i>{Length: ' . strlen($str) . '}</i>';

        if ($debug) {
            $backTraces = function_exists('debug_backtrace') ? debug_backtrace() : array();

            echo '<ul style="margin:15px 0; padding:15px; list-style-position:inside; background: #FAFAFA; border: 1px solid #DDD; line-height: 1.4;">';

            foreach ($backTraces as $backTrace) {
                echo '<li>';
                echo '<b>File:</b> ' . $backTrace['file'] . '  <b>Line:</b> ' . $backTrace['line'] . (isset($backTrace['class']) ? '  <b>Class:</b> ' . $backTrace['class'] : '') . (isset($backTrace['class']) ? '  <b>Function:</b> ' . $backTrace['function'] : '');
                echo '</li>';
            }

            echo '<li><b>Current Memory Usage:</b> ' . vpCalculateSize(memory_get_usage()) . '</li>';
            echo '<li><b>Peak Memory Usage:</b> ' . vpCalculateSize(memory_get_peak_usage()) . '</li>';

            echo '</ul>';
        }

        echo '<br/>';
        echo '</pre>';
    }
}

// Function to calculate file size
if (!function_exists('vpCalculateSize')) {
    function vpCalculateSize($mem_usage)
    {
        if ($mem_usage < 1024) {
            $result = $mem_usage . ' bytes';
        } elseif ($mem_usage < 1048576) {
            $result = round($mem_usage / 1024, 2) . ' KB';
        } else {
            $result = round($mem_usage / 1048576, 2) . ' MB';
        }

        return $result;
    }
}
