/**
 * @package      VP Conversion Tracking
 *
 * @copyright    Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license      GNU General Public License version 2 or later; see LICENSE.txt
 * @authors      Abhishek Das <info@virtueplanet.com>
 * @link         https://www.virtueplanet.com
 */

!(function($, win, doc) {
	var setFieldAsRequired = function(field) {
		var $field = $(field),
			id = $field.attr('id'),
			$label = id ? $('label[for="' + id + '"]') : null;
		
		$field.attr('required', true);
		
		if($label && $label.length && !$label.find('.star').length) {
			$('<span></span>').addClass('star').html('&nbsp;*').appendTo($label);
		}
	};
	
	var unsetFieldAsRequired = function(field) {
		var $field = $(field),
			id = $field.attr('id'),
			$label = id ? $('label[for="' + id + '"]') : null;
		
		$field.removeAttr('required').attr('aria-invalid', false).removeClass('invalid');
		
		if($label && $label.length) {
			$label.find('.star').remove();
			$label.removeClass('invalid');
		}
	};

	$(function() {
		
		$('#jform_params_thankyou_page').on('change loaded', function() {
			var $menu_field = $('#jform_params_thankyou_menuitem');
			
			if($(this).val() == 'custom' && $menu_field.length) {
				setFieldAsRequired($menu_field[0]);
			} else {
				unsetFieldAsRequired($menu_field[0]);
			}
		}).trigger('loaded');
		
		$('#jform_params_analytics_method, input[name="jform[params][google_analytics_loaded]"], input[name="jform[params][enable_google_ecommerce]"]').on('change loaded', function() {
			var $method = $('select#jform_params_analytics_method'),
				$loaded = $('input[name="jform[params][google_analytics_loaded]"]:checked'),
				$enabled = $('input[name="jform[params][enable_google_ecommerce]"]:checked'),
				$client_id = $('#jform_params_google_analytics_client_id'),
				$gtm_id = $('#jform_params_analytics_gtm_container_id');
			
			if(!$method.length || !$loaded.length || !$enabled.length || !$client_id.length || !$gtm_id.length) {
				return false;
			}
			
			if($enabled.val() == 0 || $loaded.val() == 1) {
				unsetFieldAsRequired($gtm_id[0]);
				unsetFieldAsRequired($client_id[0]);
			} else {
				var method = $method.val();

				if(method == 'analytics' || method == 'gtag') {
					setFieldAsRequired($client_id[0]);
					unsetFieldAsRequired($gtm_id[0]);
				} else if(method == 'gtm') {
					setFieldAsRequired($gtm_id[0]);
					unsetFieldAsRequired($client_id[0]);
				}
			}
		});
		
		$('input[name="jform[params][enable_google_ecommerce]"]').trigger('loaded');
		
		$('#jform_params_adwords_method, input[name="jform[params][global_adwords_installed]"], input[name="jform[params][enable_adwords_tracking]"]').on('change loaded', function() {
			var $method = $('select#jform_params_adwords_method'),
				$loaded = $('input[name="jform[params][global_adwords_installed]"]:checked'),
				$enabled = $('input[name="jform[params][enable_adwords_tracking]"]:checked'),
				$conversion_id = $('#jform_params_adwords_conversion_id'),
				$conversion_label = $('#jform_params_adwords_conversion_label'),
				$gtm_id = $('#jform_params_adwords_gtm_container_id');
			
			if(!$method.length || !$loaded.length || !$enabled.length || !$conversion_id.length || !$conversion_label.length || !$gtm_id.length) {
				return false;
			}
			
			if($enabled.val() == 0) {
				unsetFieldAsRequired($gtm_id[0]);
				unsetFieldAsRequired($conversion_id[0]);
				unsetFieldAsRequired($conversion_label[0]);
			} else {
				var method = $method.val();
				
				if(method == 'gtag') {
					setFieldAsRequired($conversion_id[0]);
					setFieldAsRequired($conversion_label[0]);
					unsetFieldAsRequired($gtm_id[0]);
				} else if(method == 'gtm') {
					unsetFieldAsRequired($conversion_id[0]);
					unsetFieldAsRequired($conversion_label[0]);
					
					if($loaded.val() == 0) {
						setFieldAsRequired($gtm_id[0]);
					} else {
						unsetFieldAsRequired($gtm_id[0]);
					}
				}
			}
		});
		
		$('#jform_params_adwords_method').trigger('loaded');
		
		$('input[name="jform[params][enable_facebook]"], input[name="jform[params][base_fb_pixel_installed]"]').on('change loaded', function() {
			var $enabled = $('input[name="jform[params][enable_facebook]"]:checked'),
				$installed = $('input[name="jform[params][base_fb_pixel_installed]"]:checked'),
				$pixel_id = $('input[name="jform[params][fb_pixel_id]"]');
			
			if(!$enabled.length || !$installed.length || !$pixel_id.length) {
				return false;
			}
			
			if($enabled.val() == 0 || $installed.val() == 1) {
				unsetFieldAsRequired($pixel_id[0]);
			} else {
				setFieldAsRequired($pixel_id[0]);
			}
		});
		
		$('input[name="jform[params][enable_facebook]"]').trigger('loaded');
		
		$('.vp-group-heading').closest('.control-group').addClass('is-heading');
		
		$('input[name="jform[params][analytics_gtm_container_id]"]').on('blur', function() {
			var $adwords_gtm_id = $('input[name="jform[params][adwords_gtm_container_id]"]');
			if(!$adwords_gtm_id.val()) {
				$adwords_gtm_id.val($(this).val()).trigger('blur');
			}
		});
	});
})(jQuery, window, document);