<?php
/**
 * @package      VP Conversion Tracking
 *
 * @copyright    Copyright (C) 2012-2023 VirtuePlanet Services LLP. All rights reserved.
 * @license      GNU General Public License version 2 or later; see LICENSE.txt
 * @authors      Abhishek Das <info@virtueplanet.com>
 * @link         https://www.virtueplanet.com
 */

defined('_JEXEC') or die;

$cellWidth    = array();
$per_row_lg   = $this->params->get('products_per_row_lg', 4);
$cellWidth[]  = 'col-lg-' . floor(12/$per_row_lg);
$per_row_md   = $this->params->get('products_per_row_md', 3);
$cellWidth[]  = 'col-md-' . floor(12/$per_row_md);
$per_row_sm   = $this->params->get('products_per_row_sm', 2);
$cellWidth[]  = 'col-sm-' . floor(12/$per_row_sm);
$per_row_xs   = $this->params->get('products_per_row_xs', 1);
$cellWidth[]  = 'col-xs-' . floor(12/$per_row_xs);
$cellWidth    = implode(' ', array_reverse($cellWidth));

$price_types  = (array) $this->params->get('price_types', array('salesPrice'));

$price_labels = array(
	'basePrice' => 'COM_VIRTUEMART_PRODUCT_BASEPRICE',
	'basePriceVariant' => 'COM_VIRTUEMART_PRODUCT_BASEPRICE_VARIANT',
	'variantModification' => 'COM_VIRTUEMART_PRODUCT_VARIANT_MOD',
	'basePriceWithTax' => 'COM_VIRTUEMART_PRODUCT_BASEPRICE_WITHTAX',
	'salesPriceWithDiscount' => 'COM_VIRTUEMART_PRODUCT_SALESPRICE_WITH_DISCOUNT',
	'salesPrice' => 'COM_VIRTUEMART_PRODUCT_SALESPRICE',
	'discountedPriceWithoutTax' => 'COM_VIRTUEMART_PRODUCT_SALESPRICE_WITHOUT_TAX',
	'priceWithoutTax' => 'COM_VIRTUEMART_PRODUCT_SALESPRICE_WITHOUT_TAX',
	'discountAmount' => 'COM_VIRTUEMART_PRODUCT_DISCOUNT_AMOUNT',
	'taxAmount' => 'COM_VIRTUEMART_PRODUCT_TAX_AMOUNT'
);

$lg = 0;
$md = 0;
$sm = 0;
$xs = 0;
?>
<?php if(!empty($this->products)) : ?>
	<?php $remaining = count($this->products); ?>
	<div class="vpct-products">
		<div class="row">
			<?php foreach($this->products as $product) : ?>
				<?php 
				$lg++;
				$md++;
				$sm++;
				$xs++;
				$remaining--;
				$ask_page_url = JRoute::_('index.php?option=com_virtuemart&view=productdetails&task=askquestion&virtuemart_product_id=' . $product->virtuemart_product_id .
				                          '&virtuemart_category_id=' . $product->virtuemart_category_id);
				?>
				<div class="vpct-product <?php echo $cellWidth ?>">
					<div class="vpct-product-inner">
						<div class="vpct-product-image-container">
							<a href="<?php echo $product->link; ?>">
								<?php echo $product->images[0]->displayMediaThumb('class="img-responsive"', false); ?>
							</a>
						</div>
						<div class="vpct-product-name-container">
							<h4 class="vpct-product-name">
								<a href="<?php echo $product->link; ?>" title="<?php echo $product->product_name; ?>" class="hover-invert"><?php echo $product->product_name; ?></a>
							</h4>
						</div>
						<div class="vpct-product-price-container">
							<div class="product-price" id="productPrice<?php echo $product->virtuemart_product_id ?>">
								<?php if($product->prices['salesPrice'] <=0 && VmConfig::get('askprice', 1) && isset($product->images[0]) && !$product->images[0]->file_is_downloadable) : ?>
									<a class="btn btn-info btn-sm ask-a-question" href="<?php echo $ask_page_url ?>" rel="nofollow" ><?php echo JText::_ ('COM_VIRTUEMART_PRODUCT_ASKPRICE') ?></a>
								<?php else :
									foreach($price_types as $price_type)
									{
										$label = $this->params->get('show_price_label', 0) && isset($price_labels[$price_type]) ? $price_labels[$price_type] : '';
										
										if($price_type == 'basePriceWithTax')
										{
											if (round($product->prices['basePriceWithTax'], $this->currency->_priceConfig['salesPrice'][1]) 
											    != round($product->prices['salesPrice'], $this->currency->_priceConfig['salesPrice'][1]))
											{
												echo '<span class="price-crossed">' . $this->currency->createPriceDiv ('basePriceWithTax', $label, $product->prices) . "</span>";
											}
										}
										elseif($price_type == 'salesPriceWithDiscount')
										{
											if (round($product->prices['salesPriceWithDiscount'], $this->currency->_priceConfig['salesPrice'][1]) 
											    != round($product->prices['salesPrice'], $this->currency->_priceConfig['salesPrice'][1]))
											{
												echo $this->currency->createPriceDiv('salesPriceWithDiscount', $label, $product->prices);
											}
										}
										else
										{
											if($price_type == 'unitPrice' && $this->params->get('show_price_label', 0))
											{
												$label = JText::sprintf('COM_VIRTUEMART_PRODUCT_UNITPRICE', JText::_('COM_VIRTUEMART_UNIT_SYMBOL_' . $product->product_unit));
											}
											
											echo $this->currency->createPriceDiv($price_type, $label, $product->prices);
										}
									}
								endif; ?>
							</div>
						</div>
					</div>
				</div>
				<?php if($lg == $per_row_lg) : ?>
					<div class="clearfix visible-lg"></div>
					<?php $lg = 0; ?>
				<?php elseif(empty($remaining)) : ?>
					<div class="clearfix visible-lg"></div>
				<?php endif; ?>
				<?php if($md == $per_row_md) : ?>
					<div class="clearfix visible-md"></div>
					<?php $md = 0; ?>
				<?php elseif(empty($remaining)) : ?>
					<div class="clearfix visible-md"></div>
				<?php endif; ?>
				<?php if($sm == $per_row_sm) : ?>
					<div class="clearfix visible-sm"></div>
					<?php $sm = 0; ?>
				<?php elseif(empty($remaining)) : ?>
					<div class="clearfix visible-sm"></div>
				<?php endif; ?>
				<?php if($xs == $per_row_xs) : ?>
					<div class="clearfix visible-xs"></div>
					<?php $xs = 0; ?>
				<?php elseif(empty($remaining)) : ?>
					<div class="clearfix visible-xs"></div>
				<?php endif; ?>
			<?php endforeach; ?>
		</div>
	</div>
<?php endif; ?>